.msgtags {
  font-weight: bold;
  color: var(--warning-color);
}

.progress_trans {
  color: var(--accent-color);
}

.fuzzy,
.progress_fuzzy {
  color: var(--warning-color);
}

.fuzzy {
  font-style: italic;
}

.untranslated,
.progress_untranslated {
  color: var(--error-color);
}

.untranslated {
  font-weight: bold;
}

.message-table-row {
  padding-top: 3px;
  padding-bottom: 3px;
}

.message-table-row-header {
  padding-top: 3px;
  padding-bottom: 3px;
}

textview.inline,
textview.inline text {
  background: none;
}

textview.inline {
  padding: 6px;
}

notebook.translation-notebook header {
 border-bottom-style: none;
}

.tab-bottom-bar:backdrop > * {
  filter: opacity(.5);
  transition: 200ms ease-in-out;
}
